@@ -13,7 +13,7 @@ use Moo;
 no warnings qw(experimental::signatures);
 use namespace::clean;
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 tie my %nc,  "Tie::Hash::NamedCapture";
 tie my %nca, "Tie::Hash::NamedCapture", all => 1;
@@ -23,16 +23,18 @@ has regex => (
 );
 
 sub match($self, $string) {
-    $string =~ $self->regex;
-    return $self->collect;
+    my $success = $string =~ $self->regex;
+
+    return $self->collect($success);
 }
 
 sub match_all($self, $string) {
     my $regex = $self->regex;
+    my $success;
     my @matches;
 
-    while($string =~ /$regex/g) {
-        push @matches, $self->collect;
+    while($success = $string =~ /$regex/g) {
+        push @matches, $self->collect($success);
     }
 
     return Regex::Object::Matches->new(
@@ -40,10 +42,22 @@ sub match_all($self, $string) {
     );
 }
 
-sub collect {
+sub collect($, $success =  undef) {
+    my $match;
+
+    if (defined $success) {
+        # Because of quirk with built-in $MATCH - in has last success match.
+        $match   = $success ? $MATCH : undef;
+    } else {
+        # Okay, you have not passed success, then we have no choice and have to rely on $MATCH.
+        $success = defined $MATCH;
+        $match   = $MATCH;
+    }
+
     return Regex::Object::Match->new(
+        success            => $success,
         prematch           => $PREMATCH,
-        match              => $MATCH,
+        match              => $match,
         postmatch          => $POSTMATCH,
         last_paren_match   => $LAST_PAREN_MATCH,
         captures           => _collect_captures(),
@@ -120,10 +134,11 @@ version 1.24
     # Works with match regex
 
     my $re = Regex::Object->new;
+    my $success;
     my @matches;
 
-    while ('John Doe Eric Lide Hans Zimmermann' =~ /(?<name>\w+?) (?<surname>\w+)/g) {
-        my $match = $re->collect;
+    while ($success = John Doe Eric Lide Hans Zimmermann' =~ /(?<name>\w+?) (?<surname>\w+)/g) {
+        my $match = $re->collect($success);
         push @matches, $match;
     }
 
@@ -184,12 +199,14 @@ Execute while loop on regex with g modifier and returns Regex::Object::Matches c
 
     my $matches = $re->match_all('John Doe Eric Lide');
 
-=head3 collect()
+=head3 collect($success = undef)
 
 Returns Regex::Object::Match result DTO filled with values from the nearest global match expression.
 
-    $string =~ /(\w*)/
-    my $result = $re->collect;
+    my $success = $string =~ /(\w*)/
+    my $result = $re->collect($success);
+
+ATTENTION!! Always pass $success, otherwise strange behavior is possible, because of built-in $MATCH saving last success.
 
 =head2 Regex::Object::Match METHODS
 
